aboutsummaryrefslogtreecommitdiffstats
path: root/csit/run-project-csit.sh
diff options
context:
space:
mode:
Diffstat (limited to 'csit/run-project-csit.sh')
-rwxr-xr-xcsit/run-project-csit.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/csit/run-project-csit.sh b/csit/run-project-csit.sh
index 6a4a9bb3..a3837b03 100755
--- a/csit/run-project-csit.sh
+++ b/csit/run-project-csit.sh
@@ -3,7 +3,7 @@
# Copyright 2016-2017 Huawei Technologies Co., Ltd.
# Modification Copyright 2019 © Samsung Electronics Co., Ltd.
# Modification Copyright 2021 © AT&T Intellectual Property.
-# Modification Copyright 2021-2022 Nordix Foundation.
+# Modification Copyright 2021-2023 Nordix Foundation.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
@@ -178,9 +178,9 @@ rm -rf "${WORKSPACE}/csit/archives/${PROJECT}"
mkdir -p "${WORKSPACE}/csit/archives/${PROJECT}"
# Run installation of prerequired libraries
-source_safely "${SCRIPTS}/prepare-csit.sh"
+source_safely "${SCRIPTS}/prepare-robot-env.sh"
-# Activate the virtualenv containing all the required libraries installed by prepare-csit.sh
+# Activate the virtualenv containing all the required libraries installed by prepare-robot-env.sh
source_safely "${ROBOT_VENV}/bin/activate"
WORKDIR=$(mktemp -d)